"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite.
keywords = [
]

#: List of input files
inp_files = [
"t01.in",
"t02.in",
"t03.in",
"t04.in",
"t05.in",
"t06.in",
"t07.in",
"t08.in",
"t09.in",
"t10.in",
"t11.in",
"t12.in",
"t13.in",
"t14.in",
"t15.in",
"t16.in",
"t17.in",
"t18.in",
"t19.in",
"t20.in",
"t21.in",
"t22.in",
"t30.in",
"t31.in",
"t32.in",
"t33.in",
"t34.in",
"t35.in",
"t36.in",
"t37.in",
"t41.in",
"t42.in",
"t43.in",
"t44.in",
"t45.in",
"t46.in",
"t47.in",
"t48.in",
"t49.in",
"t50.in",
"t51.in",
"t55.in",
"t56.in",
"t57.in",
"t61.in",
"t62.in",
"t63.in",
"t64.in",
"t65.in",
"t66.in",
"t67.in",
"t68.in",
"t69.in",
"t70.in",
"t71.in",
"t72.in",
"t73.in",
"t74.in",
"t75.in",
"t76.in",
"t77.in",
"t78.in",
"t79.in",
"t80.in",
#Nonlinear + Second order Sternheimer
"t81.in",
"t82.in",
"t83.in",
"t84.in",
"t85.in",
"t86.in",
"t87.in",
"t88.in",
"t89.in",
#GW-soc
"t90.in",
"t91.in",
"t92.in",
"t93.in",
]
